@@ -79,11 +79,13 @@
 
 void spw_free (/*@out@*/ /*@only@*/struct spwd *spent)
 {
-	free (spent->sp_namp);
-	if (NULL != spent->sp_pwdp) {
-		memzero (spent->sp_pwdp, strlen (spent->sp_pwdp));
-		free (spent->sp_pwdp);
+	if (spent != NULL) {
+		free (spent->sp_namp);
+		if (NULL != spent->sp_pwdp) {
+			memzero (spent->sp_pwdp, strlen (spent->sp_pwdp));
+			free (spent->sp_pwdp);
+		}
+		free (spent);
 	}
-	free (spent);
 }
 
