@@ -328,7 +328,7 @@ static int new_password (const struct passwd *pw)
 
 		/*
 		 * If enabled, warn about weak passwords even if you are
-		 * root (enter this password again to use it anyway). 
+		 * root (enter this password again to use it anyway).
 		 * --marekm
 		 */
 		if (amroot && !warned && getdef_bool ("PASS_ALWAYS_WARN")
@@ -490,9 +490,12 @@ static void print_status (const struct passwd *pw)
 		               ((long long)sp->sp_max * SCALE) / DAY,
 		               ((long long)sp->sp_warn * SCALE) / DAY,
 		               ((long long)sp->sp_inact * SCALE) / DAY);
-	} else {
+	} else if (NULL != pw->pw_passwd) {
 		(void) printf ("%s %s\n",
 		               pw->pw_name, pw_status (pw->pw_passwd));
+	} else {
+		(void) fprintf(stderr, _("%s: malformed password data obtained for user %s\n"),
+		               Prog, pw->pw_name);
 	}
 }
 
@@ -1042,7 +1045,7 @@ int main (int argc, char **argv)
 		STRFCPY (crypt_passwd, cp);
 
 		/*
-		 * See if the user is permitted to change the password. 
+		 * See if the user is permitted to change the password.
 		 * Otherwise, go ahead and set a new password.
 		 */
 		check_password (pw, sp);
@@ -1106,7 +1109,7 @@ int main (int argc, char **argv)
 			(void) printf (_("%s: password changed.\n"), Prog);
 #endif				/* USE_PAM */
 		} else {
-			(void) printf (_("%s: password expiry information changed.\n"), Prog);
+			(void) printf (_("%s: password changed.\n"), Prog);
 		}
 	}
 
