@@ -295,6 +295,21 @@ static void prepare_pam_close_session (void)
 	sigset_t ourset;
 	int status;
 	int ret;
+	struct sigaction action;
+
+	/* reset SIGCHLD handling to default */
+	action.sa_handler = SIG_DFL;
+	sigemptyset (&action.sa_mask);
+	action.sa_flags = 0;
+	if (0 == caught && sigaction (SIGCHLD, &action, NULL) != 0) {
+		fprintf (stderr,
+		         _("%s: signal masking malfunction\n"),
+		         Prog);
+		SYSLOG ((LOG_WARN, "Will not execute %s", shellstr));
+		closelog ();
+		exit (1);
+		/* Only the child returns. See above. */
+	}
 
 	pid_child = fork ();
 	if (pid_child == 0) {	/* child shell */
@@ -318,11 +333,7 @@ static void prepare_pam_close_session (void)
 		caught = SIGTERM;
 	}
 	if (0 == caught) {
-		struct sigaction action;
-
 		action.sa_handler = catch_signals;
-		sigemptyset (&action.sa_mask);
-		action.sa_flags = 0;
 		sigemptyset (&ourset);
 
 		if (   (sigaddset (&ourset, SIGTERM) != 0)
@@ -397,22 +408,28 @@ static void prepare_pam_close_session (void)
 		snprintf (kill_msg, sizeof kill_msg, _(" ...killed.\n"));
 		snprintf (wait_msg, sizeof wait_msg, _(" ...waiting for child to terminate.\n"));
 
+		/* Any signals other than SIGCHLD and SIGALRM will no longer have any effect,
+		 * so it's time to block all of them. */
+		sigfillset (&ourset);
+		if (sigprocmask (SIG_BLOCK, &ourset, NULL) != 0) {
+			fprintf (stderr, _("%s: signal masking malfunction\n"), Prog);
+			kill_child (0);
+			/* Never reach (_exit called). */
+		}
+
+		/* Send SIGKILL to the child if it doesn't
+		 * exit within 2 seconds (after SIGTERM) */
 		(void) signal (SIGALRM, kill_child);
 		(void) signal (SIGCHLD, catch_signals);
 		(void) alarm (2);
 
-		sigemptyset (&ourset);
-		if ((sigaddset (&ourset, SIGALRM) != 0)
-		    || (sigprocmask (SIG_BLOCK, &ourset, NULL) != 0)) {
-			fprintf (stderr, _("%s: signal masking malfunction\n"), Prog);
-			kill_child (0);
-		} else {
-			while (0 == waitpid (pid_child, &status, WNOHANG)) {
-				sigsuspend (&ourset);
-			}
-			pid_child = 0;
-			(void) sigprocmask (SIG_UNBLOCK, &ourset, NULL);
+		(void) sigdelset (&ourset, SIGALRM);
+		(void) sigdelset (&ourset, SIGCHLD);
+
+		while (0 == waitpid (pid_child, &status, WNOHANG)) {
+			sigsuspend (&ourset);
 		}
+		pid_child = 0;
 
 		(void) fputs (_(" ...terminated.\n"), stderr);
 	}
@@ -508,13 +525,13 @@ static void check_perms_nopam (const struct passwd *pw)
 
 	if (strcmp (pw->pw_passwd, "") == 0) {
 		char *prevent_no_auth = getdef_str("PREVENT_NO_AUTH");
-		if(prevent_no_auth == NULL) {
+		if (prevent_no_auth == NULL) {
 			prevent_no_auth = "superuser";
 		}
-		if(strcmp(prevent_no_auth, "yes") == 0) {
+		if (strcmp(prevent_no_auth, "yes") == 0) {
 			fprintf(stderr, _("Password field is empty, this is forbidden for all accounts.\n"));
 			exit(1);
-		} else if( (pw->pw_uid == 0)
+		} else if ((pw->pw_uid == 0)
 				&& (strcmp(prevent_no_auth, "superuser") == 0)) {
 			fprintf(stderr, _("Password field is empty, this is forbidden for super-user.\n"));
 			exit(1);
@@ -579,7 +596,7 @@ static void check_perms_nopam (const struct passwd *pw)
 	oldsig = signal (SIGQUIT, die);
 
 	/*
-	 * See if the system defined authentication method is being used. 
+	 * See if the system defined authentication method is being used.
 	 * The first character of an administrator defined method is an '@'
 	 * character.
 	 */
@@ -1156,12 +1173,9 @@ int main (int argc, char **argv)
 		}
 	}
 
-	/*
-	 * PAM_DATA_SILENT is not supported by some modules, and
-	 * there is no strong need to clean up the process space's
-	 * memory since we will either call exec or exit.
-	pam_end (pamh, PAM_SUCCESS | PAM_DATA_SILENT);
-	 */
+#ifdef USE_PAM
+	(void) pam_end (pamh, PAM_SUCCESS | PAM_DATA_SILENT);
+#endif
 
 	endpwent ();
 	endspent ();
